/* -------------------------------------------------------------------------*
 * Samples for the Attolic True Studio and the GCC                          *
 * Copyright (C) Lucjan Bryndza <lucjan.bryndza@ep.com.pl>  27.11.2010      *
 * Example No7 for the STM32 Butterfly2 and KAMODTFT2                       *
 * Joystick move lines up, down, left , right                               *
 *                                                                          *
 * http://www.boff.pl                                                       *
 * -------------------------------------------------------------------------*/

#include "stm32f10x_lib.h"
#include "system.h"
#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>
#include "time.h"
#include "n6610_lcd.h"

/* ----------------------------------------------------------------------- */
//Joy configuration for the STM32 butterfly 1 and 2
#ifdef STM32_BUTTERFLY_1 /* Butterfly 1 */

#define JOY_PORT GPIOE
#define JOY_PORT_APB2 RCC_APB2Periph_GPIOE
#define JOY_PIN_L 12
#define JOY_PIN_R 11
#define JOY_PIN_D 10
#define JOY_PIN_U 9
#define JOY_PIN_OK 8

#else /* Butterfly 2 */

#define JOY_PORT GPIOC
#define JOY_PORT_APB2 RCC_APB2Periph_GPIOC
#define JOY_PIN_L 11
#define JOY_PIN_R 10
#define JOY_PIN_D 9
#define JOY_PIN_U 8
#define JOY_PIN_OK 7

#endif /*STM32_BUTTERFLY_1*/

#define JOY_BITS ((1<<JOY_PIN_L) | (1<<JOY_PIN_R) | (1<<JOY_PIN_D) | (1<<JOY_PIN_U) | (1<<JOY_PIN_OK))


/* ----------------------------------------------------------------------- */

enum keys
{
   JOY_OK = 0x01,
   JOY_U =  0x02,
   JOY_D =  0x04,
   JOY_R =  0x08,
   JOY_L =  0x10
};

//Get joy keystate
static inline int joy_keys(void)
{
    return (~io_get_mask(JOY_PORT, JOY_BITS) & JOY_BITS) >> JOY_PIN_OK;
}


/* ----------------------------------------------------------------------- */
//Draw horizontal line
static void draw_hline(int x, int color)
{
       for(int y=1;y<MAX_NLCD_Y;y++)
       {
	  nlcd_set_pixel(x,y,color);
       }
}

/* ----------------------------------------------------------------------- */
//Draw vertical line
static void draw_vline(int y, int color)
{
       for(int x=1;x<MAX_NLCD_X;x++)
       {
	  nlcd_set_pixel(x,y,color);
       }
}

/* ----------------------------------------------------------------------- */
//KBD Debounce time
#define KBD_DEBOUNCE_TIME 10
//Vertical line color
#define VLINE_COLOR 0x00f
//Horizontal line color
#define HLINE_COLOR 0xf00
//Background color
#define BACKGROUND_COLOR 0
/* ----------------------------------------------------------------------- */
//Main function
int main(void)
{

   //JOY pin configuration input pullup VCC
    RCC->APB2ENR |= JOY_PORT_APB2;
    io_config_ext(JOY_PORT, JOY_BITS, GPIO_MODE_INPUT, GPIO_CNF_IN_PULLUP );
    io_set_clr_mask( JOY_PORT, JOY_BITS, JOY_BITS );
    //Initialize system timer
    time_init();
    //Initialize the color display
    nlcd_init();  
    //Clear screen
    nlcd_clear_screen();
    //Draw initial lines
    draw_hline(1,HLINE_COLOR);
    draw_vline(1,VLINE_COLOR);
    for(int x=1,y=1,px=1,py=1;;)
    {
        //Read joy state
        int jstate1 = joy_keys();
        wait_ms(KBD_DEBOUNCE_TIME);
        int jstate2 = joy_keys();
        if(jstate1 && jstate1==jstate2)
        {
            //If key pressed get position
	    switch(jstate1)
            {
                case JOY_U: if(y<MAX_NLCD_Y-1) y++;  break;
                case JOY_D: if(y>1) y--;  break;
                case JOY_L: if(x>1) x--;  break;
                case JOY_R: if(x<MAX_NLCD_X-1) x++; break;
                case JOY_OK: break;
            }
            //Draw lines , clear previous lines
            draw_hline( x,HLINE_COLOR );
            draw_vline( y,VLINE_COLOR );
            if(px!=x)	    
		draw_hline( px, BACKGROUND_COLOR );
            if(py!=y)
		draw_vline( py, BACKGROUND_COLOR );
            py=y; px=x;
        }
    }
    return 0;
}

/* ----------------------------------------------------------------------- */

